<?php
/**
 * WP ALLSTARS Admin Manager
 * 
 * Main controller for the plugin's admin interface. Responsible for:
 * - Registering the admin menu item
 * - Enqueueing admin scripts and styles
 * - Handling AJAX requests for settings updates
 * - Rendering the admin page with tabs
 * - Managing plugin settings registration
 *
 * @package WP_ALLSTARS
 * @since 0.2.0
 */

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}

/**
 * WP_Allstars_Admin_Manager class
 * 
 * Centralizes all admin-related functionality for the WP ALLSTARS plugin.
 */
class WP_Allstars_Admin_Manager {
    
    /**
     * Initialize the class and register all hooks
     * 
     * @return void
     */
    public static function init() {
        // Register admin hooks
        add_action('admin_menu', array(__CLASS__, 'register_admin_menu'));
        add_action('wp_ajax_wp_allstars_update_option', array(__CLASS__, 'update_option'));
        add_action('admin_init', array(__CLASS__, 'register_settings'));
        add_action('admin_enqueue_scripts', array(__CLASS__, 'enqueue_admin_scripts'));
    }
    
    /**
     * Enqueue admin scripts and styles
     * 
     * Loads CSS and JavaScript only on the plugin admin page
     * to avoid conflicts with other plugins.
     * 
     * @param string $hook The current admin page hook
     * @return void
     */
    public static function enqueue_admin_scripts($hook) {
        // Only load on our plugin's admin page
        if ('settings_page_wp-allstars' !== $hook) {
            return;
        }

        // Enqueue admin stylesheet
        wp_enqueue_style(
            'wp-allstars-admin', 
            plugins_url('css/wp-allstars-admin.css', dirname(__FILE__)),
            array(),
            WP_ALLSTARS_VERSION
        );
        
        // Enqueue admin JavaScript
        wp_enqueue_script(
            'wp-allstars-admin', 
            plugins_url('js/wp-allstars-admin.js', dirname(__FILE__)), 
            array('jquery'), 
            WP_ALLSTARS_VERSION, 
            true
        );
        
        // Localize the script with necessary data for AJAX
        wp_localize_script('wp-allstars-admin', 'wpAllstars', array(
            'nonce' => wp_create_nonce('wp-allstars-nonce'),
            'ajaxurl' => admin_url('admin-ajax.php')
        ));
    }
    
    /**
     * Register plugin settings
     * 
     * Registers all settings fields with the WordPress Settings API
     * for proper data sanitization and storage.
     *
     * @return void
     */
    public static function register_settings() {
        // Register settings for each tab as needed
        register_setting('wp_allstars_general', 'wp_allstars_general_settings');
        register_setting('wp_allstars_advanced', 'wp_allstars_advanced_settings');
        
        // Add additional settings as needed for future functionality
    }
    
    /**
     * AJAX handler for updating options
     */
    public static function update_option() {
        check_ajax_referer('wp-allstars-nonce', 'nonce');
        $option = sanitize_text_field($_POST['option']);
        $value = intval($_POST['value']);
        update_option($option, $value);
        wp_send_json_success('Option updated');
    }
    
    /**
     * Register the admin menu item
     */
    public static function register_admin_menu() {
        add_options_page(
            'WP ALLSTARS Settings',
            'WP ALLSTARS',
            'manage_options',
            'wp-allstars',
            'wp_allstars_settings_page'
        );
    }
    
    /**
     * Render the settings page
     */
    public static function render_settings_page() {
        global $tabs;
        
        $active_tab = isset($_GET['tab']) ? $_GET['tab'] : 'general';
        $active_category = isset($_GET['category']) ? $_GET['category'] : 'minimal';
        
        // Clear cache and load required files
        if ($active_tab === 'recommended') {
            WP_Allstars_Plugin_Manager::clear_plugin_cache();
            require_once ABSPATH . 'wp-admin/includes/plugin-install.php';
            wp_enqueue_script('plugin-install');
            wp_enqueue_script('updates');
            add_thickbox();
            wp_enqueue_style('wp-allstars-admin', plugins_url('css/wp-allstars-admin.css', dirname(__FILE__)));
            wp_enqueue_style('wp-allstars-plugins', plugins_url('css/wp-allstars-plugins.css', dirname(__FILE__)));
            
            // Add inline script to load plugins on page load
            wp_add_inline_script('wp-allstars-admin', '
                jQuery(document).ready(function($) {
                    if ($("#wpa-plugin-list").length && $("#wpa-plugin-list").is(":empty")) {
                        var category = "' . esc_js($active_category) . '";
                        var $container = $("#wpa-plugin-list");
                        var $loadingOverlay = $("<div class=\"wp-allstars-loading-overlay\"><span class=\"spinner is-active\"></span></div>");
                        
                        // Show loading overlay
                        $container.css("position", "relative").append($loadingOverlay);
                        
                        // AJAX request to get plugins
                        $.ajax({
                            url: ajaxurl,
                            type: "POST",
                            data: {
                                action: "wp_allstars_get_plugins",
                                category: category,
                                _wpnonce: wpAllstars.nonce
                            },
                            success: function(response) {
                                $loadingOverlay.remove();
                                if (response.success) {
                                    $container.html(response.data);
                                    // Initialize plugin action buttons
                                    if (typeof initPluginActions === "function") {
                                        initPluginActions();
                                    }
                                    
                                    // Spinners have been removed from individual cards
                                } else {
                                    $container.html("<div class=\"notice notice-error\"><p>" + response.data + "</p></div>");
                                }
                            },
                            error: function(xhr, status, error) {
                                $loadingOverlay.remove();
                                $container.html("<div class=\"notice notice-error\"><p>Failed to load plugins. Please try again. Error: " + error + "</p></div>");
                                console.error("AJAX Error:", xhr.responseText);
                            }
                        });
                    }
                });
            ');
        }
        ?>
        <div class="wrap wp-allstars-wrap">
            <div class="wp-allstars-header">
                <h1><?php echo esc_html(get_admin_page_title()); ?></h1>
                <div class="wp-allstars-header-actions">
                    <span class="wp-allstars-version"><?php echo esc_html(WP_ALLSTARS_VERSION); ?></span>
                    <a href="https://www.wpallstars.com/" target="_blank" class="button button-secondary">
                        <?php esc_html_e('Visit Website', 'wp-allstars'); ?>
                    </a>
                </div>
            </div>
            
            <div class="wp-allstars-tabs-wrapper">
                <h2 class="nav-tab-wrapper">
                    <a href="?page=wp-allstars&tab=general" class="nav-tab <?php echo $active_tab === 'general' ? 'nav-tab-active' : ''; ?>">
                        <?php esc_html_e('General', 'wp-allstars'); ?>
                    </a>
                    <a href="?page=wp-allstars&tab=advanced" class="nav-tab <?php echo $active_tab === 'advanced' ? 'nav-tab-active' : ''; ?>">
                        <?php esc_html_e('Advanced', 'wp-allstars'); ?>
                    </a>
                    <a href="?page=wp-allstars&tab=workflow" class="nav-tab <?php echo $active_tab === 'workflow' ? 'nav-tab-active' : ''; ?>">
                        <?php esc_html_e('Workflow', 'wp-allstars'); ?>
                    </a>
                    <a href="?page=wp-allstars&tab=theme" class="nav-tab <?php echo $active_tab === 'theme' ? 'nav-tab-active' : ''; ?>">
                        <?php esc_html_e('Theme', 'wp-allstars'); ?>
                    </a>
                    <a href="?page=wp-allstars&tab=recommended" class="nav-tab <?php echo $active_tab === 'recommended' ? 'nav-tab-active' : ''; ?>">
                        <?php esc_html_e('Free Plugins', 'wp-allstars'); ?>
                    </a>
                    <a href="?page=wp-allstars&tab=pro" class="nav-tab <?php echo $active_tab === 'pro' ? 'nav-tab-active' : ''; ?>">
                        <?php esc_html_e('Pro Plugins', 'wp-allstars'); ?>
                    </a>
                    <a href="?page=wp-allstars&tab=hosting" class="nav-tab <?php echo $active_tab === 'hosting' ? 'nav-tab-active' : ''; ?>">
                        <?php esc_html_e('Hosting', 'wp-allstars'); ?>
                    </a>
                    <a href="?page=wp-allstars&tab=tools" class="nav-tab <?php echo $active_tab === 'tools' ? 'nav-tab-active' : ''; ?>">
                        <?php esc_html_e('Tools', 'wp-allstars'); ?>
                    </a>
                </h2>
                
                <div class="wp-allstars-tab-content">
                    <?php
                    // Each tab's content is handled by its respective manager class
                    switch ($active_tab) {
                        case 'general':
                            WP_Allstars_Settings_Manager::display_general_tab();
                            break;
                            
                        case 'advanced':
                            WP_Allstars_Settings_Manager::display_advanced_tab();
                            break;
                            
                        case 'workflow':
                            self::display_workflow_tab();
                            break;
                            
                        case 'theme':
                            WP_Allstars_Theme_Manager::display_tab_content();
                            break;
                            
                        case 'recommended':
                            WP_Allstars_Recommended_Plugins_Manager::display_tab_content();
                            break;
                            
                        case 'pro':
                            WP_Allstars_Pro_Plugins_Manager::display_tab_content();
                            break;
                            
                        case 'hosting':
                            WP_Allstars_Hosting_Manager::display_tab_content();
                            break;
                            
                        case 'tools':
                            WP_Allstars_Tools_Manager::display_tab_content();
                            break;
                    }
                    ?>
                </div>
            </div>
        </div>
        <?php
    }
    
    /**
     * Alias for enqueue_admin_scripts to maintain compatibility with settings.php
     * 
     * @param string $hook The current admin page hook
     */
    public static function enqueue_scripts($hook) {
        self::enqueue_admin_scripts($hook);
    }
    
    /**
     * Display the Workflow tab content
     */
    public static function display_workflow_tab() {
        ?>
        <div class="wp-allstars-settings-content tab-content" id="workflow">
            <div class="wp-allstars-toggle">
                <div class="wp-allstars-toggle-header" aria-expanded="false">
                    <div class="wp-allstars-toggle-main">
                        <div class="wp-allstars-toggle-left">
                            <div class="wp-toggle-switch">
                                <input type="checkbox" 
                                       id="wp_allstars_auto_upload_images"
                                       name="wp_allstars_auto_upload_images" 
                                       value="1"
                                       <?php checked(get_option('wp_allstars_auto_upload_images', false)); ?> 
                                />
                                <span class="wp-toggle-slider"></span>
                            </div>
                            <label for="wp_allstars_auto_upload_images">
                                <?php esc_html_e('Enable Auto Upload Images', 'wp-allstars'); ?>
                            </label>
                        </div>
                    </div>
                    <p class="wp-setting-description">
                        <?php esc_html_e('Import images that have external URLs into your Media Library when saving. Consider disabling during large data imports with many external image URLs.', 'wp-allstars'); ?>
                    </p>
                </div>
                <div class="wp-allstars-toggle-settings">
                    <div class="wp-allstars-setting-row">
                        <label for="wp_allstars_max_width"><?php esc_html_e('Max Width', 'wp-allstars'); ?></label>
                        <input type="number" 
                               id="wp_allstars_max_width"
                               name="wp_allstars_max_width" 
                               value="<?php echo esc_attr(get_option('wp_allstars_max_width', 2560)); ?>" 
                        />
                        <p class="description"><?php esc_html_e('Maximum width for uploaded images in pixels.', 'wp-allstars'); ?></p>
                    </div>
                    <div class="wp-allstars-setting-row">
                        <label for="wp_allstars_max_height"><?php esc_html_e('Max Height', 'wp-allstars'); ?></label>
                        <input type="number" 
                               id="wp_allstars_max_height"
                               name="wp_allstars_max_height" 
                               value="<?php echo esc_attr(get_option('wp_allstars_max_height', 2560)); ?>" 
                        />
                        <p class="description"><?php esc_html_e('Maximum height for uploaded images in pixels.', 'wp-allstars'); ?></p>
                    </div>

                    <div class="wp-allstars-setting-row">
                        <label for="wp_exclude_urls"><?php esc_html_e('Exclude URLs', 'wp-allstars'); ?></label>
                        <textarea id="wp_exclude_urls"
                                  name="wp_exclude_urls"
                                  rows="3"
                                  placeholder="example.com&#10;another-domain.com"
                        ><?php echo esc_textarea(get_option('wp_allstars_exclude_urls', '')); ?></textarea>
                        <p class="description"><?php esc_html_e('Enter domains to exclude (one per line). Images from these domains will not be imported.', 'wp-allstars'); ?></p>
                    </div>

                    <div class="wp-allstars-setting-row">
                        <label for="wp_image_name"><?php esc_html_e('Image Name Pattern', 'wp-allstars'); ?></label>
                        <input type="text" 
                               id="wp_image_name"
                               name="wp_image_name"
                               value="<?php echo esc_attr(get_option('wp_allstars_image_name_pattern', '%filename%')); ?>"
                        />
                        <p class="description">
                            <?php esc_html_e('Available patterns:', 'wp-allstars'); ?> %filename%, %post_id%, %postname%, %timestamp%, %date%, %year%, %month%, %day%
                        </p>
                    </div>

                    <div class="wp-allstars-setting-row">
                        <label for="wp_image_alt"><?php esc_html_e('Image Alt Pattern', 'wp-allstars'); ?></label>
                        <input type="text" 
                               id="wp_image_alt"
                               name="wp_image_alt"
                               value="<?php echo esc_attr(get_option('wp_allstars_image_alt_pattern', '%filename%')); ?>"
                        />
                        <p class="description">
                            <?php esc_html_e('Available patterns:', 'wp-allstars'); ?> %filename%, %post_title%, %post_id%, %postname%, %timestamp%
                        </p>
                    </div>
                </div>
            </div>
        </div>
        <?php
    }
}
